.. Copyright (C) 2015-2016 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2016      Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2015-2016 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``unattended-upgrades`` package manages `automatic, unattended upgrades
<https://wiki.debian.org/UnattendedUpgrades>`_ of the Debian-based hosts. You
can specify what package origins are included in the unattended upgrades, as
well as specify what packages should be exempt from the upgrades, among other
things.
